@@ -5,11 +5,11 @@ package Perl::Exactly;
 #
 # http://search.cpan.org/dist/Perl-Exactly/
 #
-# Copyright (c) 2014, 2015 INABA Hitoshi <ina@cpan.org>
+# Copyright (c) 2014, 2015, 2017 INABA Hitoshi <ina@cpan.org> in a CPAN
 ######################################################################
 
 use 5.00503;
-$::VERSION = '0.02';
+$Perl::Exactly::VERSION = '0.03';
 use strict;
 
 if ($0 eq __FILE__) {
@@ -157,6 +157,7 @@ __END__
           5.018 => 'C:/Perl518/bin/perl.exe',
           5.020 => 'C:/Perl520/bin/perl.exe',
           5.022 => 'C:/Perl522/bin/perl.exe',
+          5.024 => 'C:/Perl524/bin/perl.exe',
       ) :
 
       # UNIX-like system
@@ -171,6 +172,7 @@ __END__
           5.018 => '/path/to/perl/5.018/bin/perl',
           5.020 => '/path/to/perl/5.020/bin/perl',
           5.022 => '/path/to/perl/5.022/bin/perl',
+          5.024 => '/path/to/perl/5.024/bin/perl',
       )
   }
   __END__
